==> xfburn-0.4.2.tar.bz2: xfburn-0.4.2/xfburn/xfburn-stock.h <==
/* $Id: xfburn-stock.h 5931 2008-11-03 06:14:41Z squisher $ */
/*
 * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFBURN_STOCK_H__
#define __XFBURN_STOCK_H__

G_BEGIN_DECLS;

#define XFBURN_STOCK_AUDIO_COPY           "xfburn-audio-copy"
#define XFBURN_STOCK_BLANK_CDRW           "xfburn-blank-cdrw"
#define XFBURN_STOCK_FORMAT_DVDRW         "xfburn-format-dvdrw"
#define XFBURN_STOCK_AUDIO_CD             "xfburn-audio-cd"
#define XFBURN_STOCK_BURN_CD              "xfburn-burn-cd"
#define XFBURN_STOCK_CD                   "xfburn-cd"
#define XFBURN_STOCK_DATA_COPY            "xfburn-data-copy"
#define XFBURN_STOCK_IMPORT_SESSION       "xfburn-import-session"
#define XFBURN_STOCK_NEW_DATA_COMPOSITION "xfburn-new-data-composition"

void xfburn_stock_init (void);

G_END_DECLS;

#endif

==> xfburn_0.5.0.orig.tar.bz2: xfburn-0.5.0/xfburn/xfburn-stock.h <==
/*
 * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFBURN_STOCK_H__
#define __XFBURN_STOCK_H__

G_BEGIN_DECLS;

#define XFBURN_STOCK_AUDIO_COPY           "xfburn-audio-copy"
#define XFBURN_STOCK_BLANK_CDRW           "xfburn-blank-cdrw"
#define XFBURN_STOCK_FORMAT_DVDRW         "xfburn-format-dvdrw"
#define XFBURN_STOCK_AUDIO_CD             "xfburn-audio-cd"
#define XFBURN_STOCK_BURN_CD              "xfburn"
#define XFBURN_STOCK_CD                   "xfburn-cd"
#define XFBURN_STOCK_DATA_COPY            "xfburn-data-copy"
#define XFBURN_STOCK_IMPORT_SESSION       "xfburn-import-session"
#define XFBURN_STOCK_NEW_DATA_COMPOSITION "xfburn-new-data-composition"
#define XFBURN_STOCK                      "xfburn"

void xfburn_stock_init (void);

G_END_DECLS;

#endif
